/* eslint-env browser */
/* eslint-disable no-alert */

import "./preloaded2.css";

alert("Ok");
